
import { localize } from '../../../../nls.js';
import { RawContextKey, ContextKeyExpr } from '../../../../platform/contextkey/common/contextkey.js';
import { IsWebContext } from '../../../../platform/contextkey/common/contextkeys.js';
import { RemoteNameContext } from '../../../common/contextkeys.js';
import { ChatMode } from './constants.js';

var ChatContextKeys;
(function (ChatContextKeys) {
    ChatContextKeys.responseVote = ( new RawContextKey(
        'chatSessionResponseVote',
        '',
        { type: 'string', description: ( localize(
            5108,
            "When the response has been voted up, is set to 'up'. When voted down, is set to 'down'. Otherwise an empty string."
        )) }
    ));
    ChatContextKeys.responseDetectedAgentCommand = ( new RawContextKey(
        'chatSessionResponseDetectedAgentOrCommand',
        false,
        { type: 'boolean', description: ( localize(5109, "When the agent or command was automatically detected")) }
    ));
    ChatContextKeys.responseSupportsIssueReporting = ( new RawContextKey(
        'chatResponseSupportsIssueReporting',
        false,
        { type: 'boolean', description: ( localize(5110, "True when the current chat response supports issue reporting.")) }
    ));
    ChatContextKeys.responseIsFiltered = ( new RawContextKey(
        'chatSessionResponseFiltered',
        false,
        { type: 'boolean', description: ( localize(5111, "True when the chat response was filtered out by the server.")) }
    ));
    ChatContextKeys.responseHasError = ( new RawContextKey(
        'chatSessionResponseError',
        false,
        { type: 'boolean', description: ( localize(5112, "True when the chat response resulted in an error.")) }
    ));
    ChatContextKeys.requestInProgress = ( new RawContextKey(
        'chatSessionRequestInProgress',
        false,
        { type: 'boolean', description: ( localize(5113, "True when the current request is still in progress.")) }
    ));
    ChatContextKeys.isRequestPaused = ( new RawContextKey(
        'chatRequestIsPaused',
        false,
        { type: 'boolean', description: ( localize(5114, "True when the current request is paused.")) }
    ));
    ChatContextKeys.canRequestBePaused = ( new RawContextKey(
        'chatCanRequestBePaused',
        false,
        { type: 'boolean', description: ( localize(5115, "True when the current request can be paused.")) }
    ));
    ChatContextKeys.isResponse = ( new RawContextKey('chatResponse', false, { type: 'boolean', description: ( localize(5116, "The chat item is a response.")) }));
    ChatContextKeys.isRequest = ( new RawContextKey('chatRequest', false, { type: 'boolean', description: ( localize(5117, "The chat item is a request")) }));
    ChatContextKeys.itemId = ( new RawContextKey('chatItemId', '', { type: 'string', description: ( localize(5118, "The id of the chat item.")) }));
    ChatContextKeys.lastItemId = ( new RawContextKey('chatLastItemId', [], { type: 'string', description: ( localize(5119, "The id of the last chat item.")) }));
    ChatContextKeys.editApplied = ( new RawContextKey('chatEditApplied', false, { type: 'boolean', description: ( localize(5120, "True when the chat text edits have been applied.")) }));
    ChatContextKeys.inputHasText = ( new RawContextKey('chatInputHasText', false, { type: 'boolean', description: ( localize(5121, "True when the chat input has text.")) }));
    ChatContextKeys.inputHasFocus = ( new RawContextKey('chatInputHasFocus', false, { type: 'boolean', description: ( localize(5122, "True when the chat input has focus.")) }));
    ChatContextKeys.inChatInput = ( new RawContextKey('inChatInput', false, { type: 'boolean', description: ( localize(5123, "True when focus is in the chat input, false otherwise.")) }));
    ChatContextKeys.inChatSession = ( new RawContextKey('inChat', false, { type: 'boolean', description: ( localize(5124, "True when focus is in the chat widget, false otherwise.")) }));
    ChatContextKeys.hasPromptFile = ( new RawContextKey(
        'chatPromptFileAttached',
        false,
        { type: 'boolean', description: ( localize(5125, "True when the chat has a prompt file attached.")) }
    ));
    ChatContextKeys.chatMode = ( new RawContextKey('chatMode', ChatMode.Ask, { type: 'string', description: ( localize(5126, "The current chat mode.")) }));
    ChatContextKeys.supported = ( ContextKeyExpr.or(( IsWebContext.negate()), ( RemoteNameContext.notEqualsTo('')), ( ContextKeyExpr.has('config.chat.experimental.serverlessWebEnabled'))));
    ChatContextKeys.enabled = ( new RawContextKey('chatIsEnabled', false, { type: 'boolean', description: ( localize(
        5127,
        "True when chat is enabled because a default chat participant is activated with an implementation."
    )) }));
    ChatContextKeys.extensionParticipantRegistered = ( new RawContextKey(
        'chatPanelExtensionParticipantRegistered',
        false,
        { type: 'boolean', description: ( localize(
            5128,
            "True when a default chat participant is registered for the panel from an extension."
        )) }
    ));
    ChatContextKeys.panelParticipantRegistered = ( new RawContextKey(
        'chatPanelParticipantRegistered',
        false,
        { type: 'boolean', description: ( localize(5129, "True when a default chat participant is registered for the panel.")) }
    ));
    ChatContextKeys.editingParticipantRegistered = ( new RawContextKey(
        'chatEditingParticipantRegistered',
        false,
        { type: 'boolean', description: ( localize(5130, "True when a default chat participant is registered for editing.")) }
    ));
    ChatContextKeys.chatEditingCanUndo = ( new RawContextKey(
        'chatEditingCanUndo',
        false,
        { type: 'boolean', description: ( localize(
            5131,
            "True when it is possible to undo an interaction in the editing panel."
        )) }
    ));
    ChatContextKeys.chatEditingCanRedo = ( new RawContextKey(
        'chatEditingCanRedo',
        false,
        { type: 'boolean', description: ( localize(
            5132,
            "True when it is possible to redo an interaction in the editing panel."
        )) }
    ));
    ChatContextKeys.extensionInvalid = ( new RawContextKey(
        'chatExtensionInvalid',
        false,
        { type: 'boolean', description: ( localize(
            5133,
            "True when the installed chat extension is invalid and needs to be updated."
        )) }
    ));
    ChatContextKeys.inputCursorAtTop = ( new RawContextKey('chatCursorAtTop', false));
    ChatContextKeys.inputHasAgent = ( new RawContextKey('chatInputHasAgent', false));
    ChatContextKeys.location = ( new RawContextKey('chatLocation', undefined));
    ChatContextKeys.inQuickChat = ( new RawContextKey('quickChatHasFocus', false, { type: 'boolean', description: ( localize(5134, "True when the quick chat UI has focus, false otherwise.")) }));
    ChatContextKeys.hasFileAttachments = ( new RawContextKey(
        'chatHasFileAttachments',
        false,
        { type: 'boolean', description: ( localize(5135, "True when the chat has file attachments.")) }
    ));
    ChatContextKeys.languageModelsAreUserSelectable = ( new RawContextKey(
        'chatModelsAreUserSelectable',
        false,
        { type: 'boolean', description: ( localize(5136, "True when the chat model can be selected manually by the user.")) }
    ));
    ChatContextKeys.Setup = {
        hidden: ( new RawContextKey('chatSetupHidden', false, true)),
        installed: ( new RawContextKey('chatSetupInstalled', false, true)),
        disabled: ( new RawContextKey('chatSetupDisabled', false, true)),
        later: ( new RawContextKey('chatSetupLater', false, true))
    };
    ChatContextKeys.Entitlement = {
        signedOut: ( new RawContextKey('chatEntitlementSignedOut', false, true)),
        canSignUp: ( new RawContextKey('chatPlanCanSignUp', false, true)),
        free: ( new RawContextKey('chatPlanFree', false, true)),
        pro: ( new RawContextKey('chatPlanPro', false, true)),
        proPlus: ( new RawContextKey('chatPlanProPlus', false, true)),
        business: ( new RawContextKey('chatPlanBusiness', false, true)),
        enterprise: ( new RawContextKey('chatPlanEnterprise', false, true))
    };
    ChatContextKeys.chatQuotaExceeded = ( new RawContextKey('chatQuotaExceeded', false, true));
    ChatContextKeys.completionsQuotaExceeded = ( new RawContextKey('completionsQuotaExceeded', false, true));
    ChatContextKeys.Editing = {
        agentModeDisallowed: ( new RawContextKey(
            'chatAgentModeDisallowed',
            undefined,
            { type: 'boolean', description: ( localize(5137, "True when agent mode is not allowed.")) }
        )),
        hasToolConfirmation: ( new RawContextKey(
            'chatHasToolConfirmation',
            false,
            { type: 'boolean', description: ( localize(5138, "True when a tool confirmation is present.")) }
        )),
    };
    ChatContextKeys.Tools = {
        toolsCount: ( new RawContextKey('toolsCount', 0, { type: 'number', description: ( localize(5139, "The count of tools available in the chat.")) }))
    };
    ChatContextKeys.Modes = {
        hasCustomChatModes: ( new RawContextKey(
            'chatHasCustomChatModes',
            false,
            { type: 'boolean', description: ( localize(5140, "True when the chat has custom chat modes available.")) }
        )),
    };
    ChatContextKeys.panelLocation = ( new RawContextKey(
        'chatPanelLocation',
        undefined,
        { type: 'number', description: ( localize(5141, "The location of the chat panel.")) }
    ));
})(ChatContextKeys || (ChatContextKeys = {}));
var ChatContextKeyExprs;
(function (ChatContextKeyExprs) {
    ChatContextKeyExprs.inEditingMode = ( ContextKeyExpr.or(( ChatContextKeys.chatMode.isEqualTo(ChatMode.Edit)), ( ChatContextKeys.chatMode.isEqualTo(ChatMode.Agent))));
})(ChatContextKeyExprs || (ChatContextKeyExprs = {}));

export { ChatContextKeyExprs, ChatContextKeys };
